summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--appdirs.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/appdirs.py b/appdirs.py
index 116e2a2..4221945 100644
--- a/appdirs.py
+++ b/appdirs.py
@@ -165,8 +165,8 @@ def user_config_dir(appname=None, appauthor=None, version=None, roaming=False):
Unix: ~/.config/<AppName> # or in $XDG_CONFIG_HOME, if defined
Win *: same as user_data_dir
- For Unix, we follow the XDG spec and support $XDG_DATA_HOME.
- That means, by deafult "~/.local/share/<AppName>".
+ For Unix, we follow the XDG spec and support $XDG_CONFIG_HOME.
+ That means, by deafult "~/.config/<AppName>".
"""
if sys.platform in [ "win32", "darwin" ]:
path = user_data_dir(appname, appauthor, None, roaming)